request
=======

.. automodule:: pyramid_localize.request
    :members: locale, locale_id, database_locales, locales


LocalizeRequestMixin
--------------------

    .. autoclass:: LocalizeRequestMixin
        :members:
